@@ -3,6 +3,7 @@ use std::fmt;
 use std::future::Future;
 use std::time::Duration;
 
+#[cfg(any(feature = "query", feature = "form", feature = "json"))]
 use serde::Serialize;
 #[cfg(feature = "json")]
 use serde_json;
@@ -15,7 +16,9 @@ use super::response::Response;
 use crate::config::{RequestConfig, TotalTimeout};
 #[cfg(feature = "multipart")]
 use crate::header::CONTENT_LENGTH;
-use crate::header::{HeaderMap, HeaderName, HeaderValue, CONTENT_TYPE};
+#[cfg(any(feature = "multipart", feature = "form", feature = "json"))]
+use crate::header::CONTENT_TYPE;
+use crate::header::{HeaderMap, HeaderName, HeaderValue};
 use crate::{Method, Url};
 use http::{request::Parts, Extensions, Request as HttpRequest, Version};
 
@@ -351,9 +354,15 @@ impl RequestBuilder {
     /// as `.query(&[("key", "val")])`. It's also possible to serialize structs
     /// and maps into a key-value pair.
     ///
+    /// # Optional
+    ///
+    /// This requires the optional `query` feature to be enabled.
+    ///
     /// # Errors
     /// This method will fail if the object you provide cannot be serialized
     /// into a query string.
+    #[cfg(feature = "query")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "query")))]
     pub fn query<T: Serialize + ?Sized>(mut self, query: &T) -> RequestBuilder {
         let mut error = None;
         if let Ok(ref mut req) = self.request {
@@ -407,10 +416,16 @@ impl RequestBuilder {
     /// # }
     /// ```
     ///
+    /// # Optional
+    ///
+    /// This requires the optional `form` feature to be enabled.
+    ///
     /// # Errors
     ///
     /// This method fails if the passed value cannot be serialized into
     /// url encoded format
+    #[cfg(feature = "form")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "form")))]
     pub fn form<T: Serialize + ?Sized>(mut self, form: &T) -> RequestBuilder {
         let mut error = None;
         if let Ok(ref mut req) = self.request {
@@ -449,10 +464,9 @@ impl RequestBuilder {
         if let Ok(ref mut req) = self.request {
             match serde_json::to_vec(json) {
                 Ok(body) => {
-                    if !req.headers().contains_key(CONTENT_TYPE) {
-                        req.headers_mut()
-                            .insert(CONTENT_TYPE, HeaderValue::from_static("application/json"));
-                    }
+                    req.headers_mut()
+                        .entry(CONTENT_TYPE)
+                        .or_insert_with(|| HeaderValue::from_static("application/json"));
                     *req.body_mut() = Some(body.into());
                 }
                 Err(err) => error = Some(crate::error::builder(err)),
@@ -464,19 +478,6 @@ impl RequestBuilder {
         self
     }
 
-    // This was a shell only meant to help with rendered documentation.
-    // However, docs.rs can now show the docs for the wasm platforms, so this
-    // is no longer needed.
-    //
-    // You should not otherwise depend on this function. It's deprecation
-    // is just to nudge people to reduce breakage. It may be removed in a
-    // future patch version.
-    #[doc(hidden)]
-    #[cfg_attr(target_arch = "wasm32", deprecated)]
-    pub fn fetch_mode_no_cors(self) -> RequestBuilder {
-        self
-    }
-
     /// Build a `Request`, which can be inspected, modified and executed with
     /// `Client::execute()`.
     pub fn build(self) -> crate::Result<Request> {
@@ -661,15 +662,14 @@ impl TryFrom<Request> for HttpRequest<Body> {
 
 #[cfg(test)]
 mod tests {
-    #![cfg(not(feature = "rustls-tls-manual-roots-no-provider"))]
+    #![cfg(not(feature = "rustls-no-provider"))]
 
-    use super::{Client, HttpRequest, Request, RequestBuilder, Version};
-    use crate::Method;
-    use serde::Serialize;
+    use super::*;
+    #[cfg(feature = "query")]
     use std::collections::BTreeMap;
-    use std::convert::TryFrom;
 
     #[test]
+    #[cfg(feature = "query")]
     fn add_query_append() {
         let client = Client::new();
         let some_url = "https://google.com/";
@@ -683,6 +683,7 @@ mod tests {
     }
 
     #[test]
+    #[cfg(feature = "query")]
     fn add_query_append_same() {
         let client = Client::new();
         let some_url = "https://google.com/";
@@ -695,6 +696,7 @@ mod tests {
     }
 
     #[test]
+    #[cfg(feature = "query")]
     fn add_query_struct() {
         #[derive(Serialize)]
         struct Params {
@@ -718,6 +720,7 @@ mod tests {
     }
 
     #[test]
+    #[cfg(feature = "query")]
     fn add_query_map() {
         let mut params = BTreeMap::new();
         params.insert("foo", "bar");
@@ -759,6 +762,7 @@ mod tests {
     }
 
     #[test]
+    #[cfg(feature = "query")]
     fn normalize_empty_query() {
         let client = Client::new();
         let some_url = "https://google.com/";
